@@ -4,12 +4,13 @@ package Catalyst::Plugin::Cache::Choose::KeyRegexes;
 
 use strict;
 use warnings;
+use MRO::Compat;
 
 sub setup {
     my $app = shift;
-    my $ret = $app->NEXT::setup( @_ );
+    my $ret = $app->maybe::next::method( @_ );
 
-    my $regexes = $app->config->{cache}{key_regexes} ||= [];
+    my $regexes = $app->_get_cache_plugin_config->{key_regexes} ||= [];
 
     die "the regex list must be an array containing regexex/backend pairs" unless ref $regexes eq "ARRAY";
 
@@ -18,7 +19,7 @@ sub setup {
 
 sub get_cache_key_regexes {
     my ( $c, %meta ) = @_;
-    @{ $c->config->{cache}{key_regexes} };
+    @{ $c->_get_cache_plugin_config->{key_regexes} };
 }
 
 sub choose_cache_backend {
@@ -30,7 +31,7 @@ sub choose_cache_backend {
         return $backend if $meta{key} =~ $re;
     }
 
-    $c->NEXT::choose_cache_backend( %meta );
+    $c->maybe::next::method( %meta );
 }
 
 __PACKAGE__;
